Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| PGL DISTRIBUICAO DE ALIMENTOS LTDA
CNPJ: 87.397.865/0021-65 Inscrição Estadual: 1090357122
Evandro Behr - RS 509 KM 08, 6645, CAMOBI, Santa Maria, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 103701 Série: 206 Data de Emissão: 04/11/2019 12:43:33
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 1187 3978 6500 2165 6520 6000 1037 0110 0094 5335
Protocolo de Autorização: 143191516323482
CONSUMIDOR
CPF: 044.272.479-97
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
320 | CARNE BOV GUISADO 2a RESF KG | 1,136 | KG | 13,9 | 15,79
606450 | ATUM SOLIDO PESCADOR OLEO 170G | 1 | UN | 8,49 | 8,49
627600010 | ATUM RALADO GDC NATURAL 170G | 1 | UN | 5,79 | 5,79
627600010 | ATUM RALADO GDC NATURAL 170G | 1 | UN | 5,79 | 5,79
524290 | PEITO PERU SEARA DEF ESCOL SAUD FAT KG | 0,428 | KG | 44,9 | 19,21
523080 | QUEIJO TIROLEZ PRATO FAT KG | 0,514 | KG | 32,9 | 16,91
128190 | MASSA ROMENA PIZZA PZ 150G | 2 | UN | 3,99 | 7,98
Valor total R$ | 79,96
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:32